Opinions & Orders | US Court of Appeals for the Federal Circuit

Jump to Navigation

## Search form

Search

- Announcements
- The Court
  - Judges
  - Advisory Council
  - Court Jurisdiction
  - Statistics
  - Library
  - Gallery
  - FAQs
  - Wireless Internet Access
  - Employment
- Cases
  - Daily Disposition Sheet
  - Opinions & Orders
- CM/ECF
  - Registration
  - eFile
  - PACER
  - Reference Materials
  - System Outages
- Clerk's Office
  - Attorney Admissions Search
  - Forms
  - Directions & Map
  - Places to Stay
- Rules of Practice
  - Notices
  - Rules
  - Top Ten Most Common Errors in Briefs and Motions
  - Pro Se
  - Guide for Motions Practice
  - Internal Operating Procedures
  - Attorney Discipline Rules
- Argument
  - Upcoming Oral Arguments
  - Notice to Counsel
  - Calendar of Sessions
  - Courtroom Decorum
  - Oral Argument Recordings
- Mediation
  - Volunteer Mediators
  - Guidelines
  - Forms
  - FAQs
- Judicial Reports

- Announcements
- The Court
  - Judges
  - Advisory Council
  - Court Jurisdiction
  - Statistics
  - Library
  - Gallery
  - FAQs
  - Wireless Internet Access
  - Employment
- Cases
  - Daily Disposition Sheet
  - Opinions & Orders
- CM/ECF
  - Registration
  - eFile
  - PACER
  - Reference Materials
  - System Outages
- Clerk's Office
  - Attorney Admissions Search
  - Forms
  - Directions & Map
  - Places to Stay
- Rules of Practice
  - Notices
  - Rules
  - Top Ten Most Common Errors in Briefs and Motions
  - Pro Se
  - Guide for Motions Practice
  - Internal Operating Procedures
  - Attorney Discipline Rules
- Argument
  - Upcoming Oral Arguments
  - Notice to Counsel
  - Calendar of Sessions
  - Courtroom Decorum
  - Oral Argument Recordings
- Mediation
  - Volunteer Mediators
  - Guidelines
  - Forms
  - FAQs
- Judicial Reports

10

- Rules of Practice
  - Notices
  - Rules
  - Pro Se
  - Guide for Motions Practice
  - Internal Operating Procedures
  - Attorney Discipline Rules
- Argument
  - Upcoming Oral Arguments
  - Notice to Counsel
  - Court Decorum
  - Calendar of Sessions
- Mediation
  - Mediators
  - Guidelines
  - Forms
- Opinions & Orders
- Oral Argument Recordings
- Judges
- Judicial Reports

## Text Size:

-A A +A

## You are here

Home Cases Opinions & Orders

# Opinions & Orders

This search contains all opinions of the Court, as well as orders selected* by the Court.
All dispositions are available in PACER.

* It contains all opinions of the Court, as well as orders selected by the Court.
The Court publishes opinions, precedential orders, all non-ministerial orders related to en banc cases, and orders disposing of mandamus petitions, on the website after issuance has occurred on the official docket.

Search By
Case Name or Appeal Number
Origin
Type
Date Range
Start date
Date
Format: 2015-07-30
End date
Date
Format: 2015-07-30

Date | Appeal Number | Origin | Case Name | Type
--- | --- | --- | --- | ---
2015-07-30 | 15-1701 | DCT | SMARTFLASH LLC v. APPLE INC. [OPINION] | Nonprecedential
2015-07-30 | 14-1464 | DCT | HIGH POINT DESIGN LLC v. BUYER'S DIRECT, INC. [OPINION] | Nonprecedential
2015-07-29 | 14-5037 | CFC | BASR PARTNERSHIP v. US [OPINION] | Precedential
2015-07-28 | 15-1104 | DCT | PETZILA, INC. v. ANSER INNOVATION LLC [OPINION] | Nonprecedential
2015-07-28 | 15-1155 | DCT | CIRCUIT CHECK INC. v. QXQ INC. [OPINION] | Precedential
2015-07-28 | 15-7052 | CAVC | HOBSON v. MCDONALD [OPINION] | Nonprecedential
2015-07-28 | 13-5110 | CFC | GROUND IMPROVEMENT TECHNIQUES v. US [OPINION] | Nonprecedential
2015-07-22 | 15-112 | DCT | IN RE POSCO [ORDER] | Precedential
2015-07-21 | 14-7122 | CAVC | CARTER v. MCDONALD [OPINION] | Precedential
2015-07-21 | 15-1499 | DCT | AMGEN INC. v. SANDOZ INC. [OPINION] | Precedential
2015-07-21 | 14-1797 | DCT | ADDICTION AND DETOXIFICATION v. CARPENTER [OPINION] | Nonprecedential
2015-07-20 | 14-1853 | PATO | JUICE GENERATION, INC. v. GS ENTERPRISES LLC [OPINION] | Precedential
2015-07-17 | 14-1547 | PATO | TRUSTEES OF COLUMBIA UNIV. v. ILLUMINA, INC. [OPINION] | Nonprecedential
2015-07-17 | 14-1808 | PATO | AIRBUS S.A.S. v. FIREPASS CORPORATION [OPINION] | Precedential
2015-07-17 | 15-1143 | DCT | L.C. ELDRIDGE SALES CO., LTD. v. JURONG SHIPYARD PTE., LTD. [RULE 36 JUDGMENT] | Nonprecedential
2015-07-17 | 15-1125 | DCT | FLORIDA ATLANTIC UNIVERSITY v. ASUS COMPUTER INTERNATIONAL [RULE 36 JUDGMENT] | Nonprecedential
2015-07-16 | 15-1059 | DCT | GENSPERA, INC. v. MHAKA [RULE 36 JUDGMENT] | Nonprecedential
2015-07-16 | 12-1289 | DCT | BIOSIG INSTRUMENTS, INC. v. NAUTILUS, INC. [ERRATA] | Precedential
2015-07-15 | 15-5004 | CFC | TRUST TITLE COMPANY v. US [RULE 36 JUDGMENT] | Nonprecedential
2015-07-15 | 14-7106 | CAVC | COOPER v. MCDONALD [RULE 36 JUDGMENT] | Nonprecedential

## Pages

- 1
- 2
- 3
- 4
- 5
- 6
- 7
- 8
- 9
- …
- next ›
- last »